package com.zy.bms.common.aspect;

import com.zy.bms.common.exception.ApiRuntimeException;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;

import java.lang.reflect.Method;
import java.util.Arrays;

/**
 * 打印日志切面
 *
 * @author yang xiao kun
 * create on 2021/2/25
 */
//@Aspect
//@Component
public class LogAspect {

    /**
     * 定义一个切入点.
     */
    @Pointcut("execution(* com.zhiyun.mqtt.service.impl..*.*(..))||execution(* com.zhiyun.mqtt.controller..*.*(..))")
    public void pointcut() {
    }

    /**
     * 方法切入点（输出方法执行概要日志）
     *
     * @param joinPoint 连接点
     * @return 原方法返回值
     */
    @Around(value = "pointcut()")
    public Object around(ProceedingJoinPoint joinPoint) {
        StringBuilder sb = buildMethodInfo(joinPoint);
        try {
            return joinPoint.proceed();
        } catch (Throwable throwable) {
            sb.append("发生异常:").append(throwable.getMessage());
            throw new ApiRuntimeException("系统错误");
        } finally {
            System.out.println(sb.toString());
        }
    }

    private StringBuilder buildMethodInfo(ProceedingJoinPoint joinPoint) {
        MethodSignature signature = (MethodSignature) joinPoint.getSignature();
        Method method = signature.getMethod();
        StringBuilder result = new StringBuilder();
        result.append("执行方法:").append(method.toGenericString())
                .append(" -- ")
                .append("入参:").append(Arrays.toString(joinPoint.getArgs()));
        return result;
    }
}
