package com.zy.bms.controller.wx;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.zy.bms.common.ServerResponse;
import com.zy.bms.common.controller.BaseController;
import com.zy.bms.model.UserDeviceRelation;
import com.zy.bms.service.DeviceService;
import com.zy.bms.service.RelationService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 用户设备绑定关系
 *
 * @author chen_yi
 * Create on 2020/8/1
 */
@RestController
@RequestMapping("omp/api/wx/relation")
public class RelationController extends BaseController {

    @Resource
    private RelationService relationService;

    @Resource
    private DeviceService deviceService;

    /**
     * 添加绑定关系
     */
    @PostMapping("bind.do")
    public ServerResponse bind(String deviceNum, String deviceName) {
        if (deviceService.getByNum(deviceNum) == null)
            return ServerResponse.createByWarning("无效设备码!");
        if (relationService.checkDeviceIsBind(deviceNum))
            return ServerResponse.createByWarning("该设备已经有用户绑定!");
        relationService.saveEntity(getUserId(), deviceNum, deviceName);
        return ServerResponse.createBySuccess();
    }

    /**
     * 解除绑定关系
     */
    @PostMapping("unbind.do")
    public ServerResponse unbind(String deviceNum) {
        relationService.unbind(deviceNum, getUserId());
        return ServerResponse.createBySuccess();
    }

    /**
     * 查询用户的所有设备
     */
    @GetMapping("getListByUserId.do")
    public ServerResponse getListByUserId() {
        return ServerResponse.createBySuccess(relationService.getListByUserId(getUserId()));
    }

    /**
     * 修改默认设备
     * 即登陆以后使用那个设备
     *
     * @param deviceNum 设备码
     */
    @PostMapping("changeDefault.do")
    public ServerResponse changeDefault(String deviceNum) {
        //删除上一个默认设备
        relationService.update(Wrappers.<UserDeviceRelation>lambdaUpdate().eq(UserDeviceRelation::getIsDefault, 1)
                .eq(UserDeviceRelation::getUserId, getUserId()).set(UserDeviceRelation::getIsDefault, 0));
        //添加新的默认设备
        relationService.update(Wrappers.<UserDeviceRelation>lambdaUpdate().eq(UserDeviceRelation::getDeviceNum, deviceNum)
                .set(UserDeviceRelation::getIsDefault, 1));
        return ServerResponse.createBySuccess();
    }
}
