package com.zy.bms.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.bms.common.io.pc.DeviceIO;
import com.zy.bms.common.vo.DeviceFullDataVo;
import com.zy.bms.mapper.DeviceMapper;
import com.zy.bms.model.Device;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 设备信息相关
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class DeviceService extends ServiceImpl<DeviceMapper, Device> {

    /**
     * 后台
     * 分页查询设备列表
     *
     * @param io 查询条件
     */
    public IPage<DeviceFullDataVo> getListPage(DeviceIO io) {
        Page<DeviceFullDataVo> page = new Page<>(io.getCurrent(), io.getSize());
        return baseMapper.getListPage(page, io);
    }

    /**
     * 批量更新设备在线状态
     */
    public void updateDeviceStatus(List<Device> devices) {
        baseMapper.updateDeviceStatus(devices);
    }

    /**
     * 通过设备 num 获取设备信息
     *
     * @param num 设备号
     */
    public Device getByNum(String num) {
        QueryWrapper<Device> queryWrapper = new QueryWrapper<Device>().eq("num", num);
        return baseMapper.selectOne(queryWrapper);
    }

    /**
     * 更新设备名称
     *
     * @param num  设备号
     * @param name 名称
     */
    public void updateName(String num, String name) {
        baseMapper.updateName(num, name);
    }

    /**
     * 通过设备 clientId 获取设备信息
     *
     * @param clientId 设备 MQTT 登录账号
     */
    public Device getByClientId(String clientId) {
        QueryWrapper<Device> queryWrapper = new QueryWrapper<Device>().eq("clientId", clientId);
        return baseMapper.selectOne(queryWrapper);
    }
}
