package com.zy.bms.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.bms.mapper.UserDeviceRelationMapper;
import com.zy.bms.model.UserDeviceRelation;
import com.zy.bms.common.vo.DeviceRelationVo;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;


/**
 * 用户设备绑定关系Service
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class RelationService extends ServiceImpl<UserDeviceRelationMapper, UserDeviceRelation> {

    @Resource
    private DeviceService deviceService;

    /**
     * 添加绑定关系
     *
     * @param userId     用户ID
     * @param deviceNum  设备随机码
     * @param deviceName 设备名称
     */
    public void saveEntity(String userId, String deviceNum, String deviceName) {
        UserDeviceRelation entity = new UserDeviceRelation();
        entity.setUserId(userId);
        entity.setDeviceNum(deviceNum);
        baseMapper.insert(entity);
        deviceService.updateName(deviceNum, deviceName);
    }

    /**
     * 通过设备号删除绑定关系
     *
     * @param deviceNum 设备号
     */
    public void unbind(String deviceNum, String userId) {
        QueryWrapper<UserDeviceRelation> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deviceNum", deviceNum);
        queryWrapper.eq("userId", userId);
        baseMapper.delete(queryWrapper);
    }

    /**
     * 查询用户绑定的设备集合
     *
     * @param userId 用户ID
     */
    public List<DeviceRelationVo> getListByUserId(String userId) {
        return baseMapper.getListByUserId(userId);
    }

    /**
     * 查询设备是否有绑定关系
     *
     * @param deviceNum 设备号
     */
    public boolean checkDeviceIsBind(String deviceNum) {
        return baseMapper.checkDeviceIsBind(deviceNum) > 0;
    }

    /**
     * 查询设备是否属于该用户
     *
     * @param userId    用户ID
     * @param deviceNum 设备码
     */
    public boolean checkDeviceIsBelongByNum(String userId, String deviceNum) {
        return baseMapper.checkDeviceIsBelongByNum(userId, deviceNum) > 0;
    }

    /**
     * 查询设备是否属于该用户
     *
     * @param userId   用户ID
     * @param deviceId 设备ID
     */
    public boolean checkDeviceIsBelongByDeviceId(String userId, String deviceId) {
        return baseMapper.checkDeviceIsBelongByDeviceId(userId, deviceId) > 0;
    }
}
